package wallet

import (
	"birdcall/internal/consts"
	"birdcall/internal/library/birdeye"
	w1 "birdcall/internal/model/birdeye/wallet"
	"encoding/json"
	"net/http"
	"net/url"
	"os"
	"strconv"
)

type Wallet struct{}

func (w *Wallet) Support() (*w1.SupportRes, error) {
	//构建基本请求连接
	baseURL := os.Getenv(consts.WALLET_URL)
	fullURL := baseURL + consts.LIST_SUPPORTED_CHAIN

	apiReq, err := http.NewRequest(consts.GET, fullURL, nil)
	if err != nil {
		return nil, err
	}
	//构建请求头
	apiReq = birdeye.MakeHeader(apiReq)

	body, err := birdeye.SendRequest(apiReq)
	if err != nil {
		return nil, err
	}

	//处理返回数据
	var res *w1.SupportRes
	err = json.Unmarshal([]byte(body), &res)
	if err != nil {
		return nil, err
	}
	return res, nil
}

//	 TransactionHistory
//		@param wallet
//		@param limit
//		@param before
//		@return *w1.TransactionHistoryRes
//		@return error
func (w *Wallet) TransactionHistory(wallet string, limit int64, before string) (*w1.TransactionHistoryRes, error) {
	//构建基本请求连接
	baseURL := os.Getenv(consts.WALLET_URL)
	params := url.Values{}
	params.Add(consts.WALLET, wallet)
	params.Add(consts.LIMIT, strconv.FormatInt(limit, 10))
	params.Add(consts.BEFORE, before)

	fullURL := baseURL + consts.TX_LIST + consts.QUESTION_MARK + params.Encode()

	apiReq, err := http.NewRequest(consts.GET, fullURL, nil)
	if err != nil {
		return nil, err
	}
	//构建请求头
	apiReq = birdeye.MakeHeader(apiReq)

	body, err := birdeye.SendRequest(apiReq)
	if err != nil {
		return nil, err
	}

	//处理返回数据
	var res *w1.TransactionHistoryRes
	err = json.Unmarshal([]byte(body), &res)
	if err != nil {
		return nil, err
	}
	return res, nil
}
